@@ -346,10 +346,13 @@ impl Kubectl {
 
     pub(crate) async fn install_statehub_cluster(&self, namespace: &str) -> anyhow::Result<()> {
         let crd = self.create_statehub_cluster_crd().await?;
-        log::debug!("Created CRD: {:#?}", crd);
+        log::debug!("Created StatehubCluster CRD: {:#?}", crd);
         let cluster = self.create_statehub_cluster(namespace).await?;
         log::debug!("Created StatehubCluster: {:#?}", cluster);
 
+        let crd = self.create_statehub_state_crd().await?;
+        log::debug!("Created State CRD: {:#?}", crd);
+
         let client = self.get_client().await?;
         let statehub_kubectl = statehub_cluster_operator::cluster::Kubectl::new(client);
         let namespace = statehub_kubectl.create_namespace(&cluster).await?;
@@ -358,15 +361,18 @@ impl Kubectl {
     }
 
     pub(crate) async fn uninstall_statehub_cluster(&self) -> anyhow::Result<()> {
-        let client = self.get_client().await?;
         let cluster = self.check_statehub_cluster_object().await?;
-        let statehub_kubectl = statehub_cluster_operator::cluster::Kubectl::new(client);
-        statehub_kubectl.delete_namespace(&cluster).await?;
+        let name = cluster.name();
+        // let client = self.get_client().await?;
+        // let statehub_kubectl = statehub_cluster_operator::cluster::Kubectl::new(client);
+        // statehub_kubectl.delete_namespace(&cluster).await?;
 
-        self.delete_statehub_cluster().await?;
+        self.delete_statehub_cluster(&name).await?;
         log::debug!("Deleted StatehubCluster");
+        self.delete_statehub_state_crd().await?;
+        log::debug!("Deleted Statehub State CRD");
         self.delete_statehub_cluster_crd().await?;
-        log::debug!("Deleted CRD");
+        log::debug!("Deleted StatehubCluster CRD");
         Ok(())
     }
 
