@@ -9,9 +9,11 @@
 #![warn(clippy::map_unwrap_or)]
 #![warn(deprecated_in_future)]
 #![warn(future_incompatible)]
+#![warn(noop_method_call)]
 #![warn(unreachable_pub)]
 #![warn(missing_debug_implementations)]
 #![warn(rust_2018_compatibility)]
+#![warn(rust_2021_compatibility)]
 #![warn(rust_2018_idioms)]
 #![warn(unused)]
 #![deny(warnings)]
