@@ -13,7 +13,6 @@ use dialoguer::{theme, Confirm, Input};
 use futures::StreamExt;
 use itertools::Itertools;
 use serde::{de, Deserialize, Serialize};
-use serde_json as json;
 use structopt::clap;
 use structopt::StructOpt;
 
@@ -191,6 +190,9 @@ enum Command {
 
         #[structopt(help = "Cleanup grace time out", long, default_value = "600s")]
         cleanup_grace: String,
+
+        #[structopt(flatten)]
+        azure: AzureCredentials,
     },
 
     #[structopt(
@@ -356,11 +358,11 @@ enum Command {
 
     #[structopt(
         about = "Manually choose primary location for volume",
-        aliases = &["set-v", "sv"],
+        aliases = &["set-p", "sp"],
         display_order(50),
         setting(clap::AppSettings::Hidden),
     )]
-    SetVolume {
+    SetPrimary {
         #[structopt(help = "State name")]
         state: v0::StateName,
         #[structopt(help = "Volume name")]
@@ -379,6 +381,18 @@ enum Command {
         state: v0::StateName,
     },
 
+    #[structopt(
+        about = "Show volume[s] info in the given state",
+        aliases = &["show-volume", "show-v", "sv"],
+        display_order(50),
+    )]
+    ShowVolumes {
+        #[structopt(help = "State name")]
+        state: v0::StateName,
+        #[structopt(help = "Volume name")]
+        volumes: Vec<v0::VolumeName>,
+    },
+
     #[structopt(
         about = "Save cluster token",
         alias = "sct",
@@ -553,6 +567,7 @@ impl Cli {
                 skip_helm,
                 provider,
                 cleanup_grace,
+                azure,
             } => {
                 let interactive = !non_interactive;
                 let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
@@ -576,6 +591,8 @@ impl Cli {
 
                 let helm = k8s::Helm::new(skip_helm);
 
+                azure.validate()?;
+
                 let register_cluster = RegisterCluster::new(
                     helm,
                     provider,
@@ -584,6 +601,7 @@ impl Cli {
                     default_state,
                     claim_unowned_states,
                     cleanup_grace,
+                    azure,
                 );
                 if interactive {
                     // Right now interactive_register_cluster() does very much the same job as
@@ -670,12 +688,13 @@ impl Cli {
                 volume,
                 wait,
             } => statehub.delete_volume(state, volume, wait).await,
-            Command::SetVolume {
+            Command::SetPrimary {
                 state,
                 volume,
                 primary,
             } => statehub.set_volume_primary(state, volume, primary).await,
             Command::ListVolumes { state } => statehub.list_volumes(state).await,
+            Command::ShowVolumes { state, volumes } => statehub.show_volumes(state, volumes).await,
             Command::SaveClusterToken { namespace, token } => {
                 statehub.save_cluster_token(namespace, token).await
             }
@@ -889,13 +908,10 @@ impl StateHub {
             name, azure
         ))?;
 
-        let azure = json::to_value(azure)?;
-        let _secret = kubectl.store_azure_credentials(&namespace, azure).await?;
-
-        let aws = json::json!({});
-        let _scret = kubectl.store_aws_credentials(&namespace, aws).await?;
-
-        Ok(())
+        let azure = Some(&azure);
+        let aws = None;
+        self.setup_credentials_helper(&kubectl, &namespace, azure, aws)
+            .await
     }
 
     async fn show_cluster(&self, name: v0::ClusterName) -> anyhow::Result<()> {
@@ -1053,6 +1069,29 @@ impl StateHub {
             .print(&self.stdout, self.json)
     }
 
+    async fn show_volumes(
+        &self,
+        state: v0::StateName,
+        volumes: Vec<v0::VolumeName>,
+    ) -> anyhow::Result<()> {
+        if volumes.is_empty() {
+            self.api
+                .get_all_volumes(state)
+                .await
+                .map(Detailed)
+                .print(&self.stdout, self.json)
+        } else {
+            for volume in volumes {
+                self.api
+                    .get_volume(&state, &volume)
+                    .await
+                    .map(Detailed)
+                    .print(&self.stdout, self.json)?;
+            }
+            Ok(())
+        }
+    }
+
     async fn set_availability(self) -> anyhow::Result<()> {
         // Ok(Output::<String>::todo()).handle_output(&self.stdout, self.json)
         anyhow::bail!(self.show(Output::<String>::todo()))
