@@ -128,3 +128,18 @@ impl Show for Condition {
         format!("{}", condition)
     }
 }
+
+impl Show for CreateStateDto {
+    fn show(&self) -> String {
+        let aws = self.locations.aws.iter().map(|dto| dto.region.into());
+        let azure = self.locations.azure.iter().map(|dto| dto.region.into());
+        let locations = aws.chain(azure).collect::<Vec<Location>>();
+
+        let locations = if locations.is_empty() {
+            String::new()
+        } else {
+            format!(" in {}", locations.show())
+        };
+        format!("Creating new state '{}'{}", self.name, locations)
+    }
+}
